@@ -1,14 +1,11 @@
 test_that("a volcano plot works with some of customizations", {
-    set.seed(1)
-
     data("exampleDESeqResults", "sigoraDatabase")
 
     interferonGenes <- sigoraDatabase %>%
         filter(pathwayName == "Interferon Signaling") %>%
         pull(ensemblGeneId)
 
-    vdiffr::expect_doppelganger(
-        "volcanoPlotExample",
+    expect_no_error(
         eruption(
             rnaseqResult=exampleDESeqResults[[1]],
             xaxis=c(-4, 4),
