@@ -1,10 +1,7 @@
 test_that("fold change heatmaps are working with some customization", {
-    set.seed(1)
-
     data("exampleDESeqResults")
 
-    vdiffr::expect_doppelganger(
-        "plotFoldChangeExample",
+    expect_no_error(
         plotFoldChange(
             inputList=exampleDESeqResults,
             pathName="Interferon alpha/beta signaling",
@@ -16,8 +13,6 @@ test_that("fold change heatmaps are working with some customization", {
 })
 
 test_that("argument 'returnData' is working.", {
-    set.seed(1)
-
     data("exampleDESeqResults")
 
     expect_type(
